@@ -28,15 +28,8 @@
 #include <gdk/gdkkeysyms.h>
 #include "gtkhtml-color-swatch.h"
 
-/* backward-compatibility cruft */
-#include "gtkhtml/gtk-compat.h"
-
 #define NUM_CUSTOM_COLORS	8
 
-#define GTKHTML_COLOR_COMBO_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), GTKHTML_TYPE_COLOR_COMBO, GtkhtmlColorComboPrivate))
-
 enum {
 	PROP_0,
 	PROP_CURRENT_COLOR,
@@ -259,8 +252,8 @@ color_combo_child_key_press_event_cb (GtkhtmlColorCombo *combo,
 {
 	GtkWidget *window = combo->priv->window;
 
-	if (!gtk_bindings_activate_event (COMPAT_BINDING_TYPE (window), event))
-		gtk_bindings_activate_event (COMPAT_BINDING_TYPE (combo), event);
+	if (!gtk_bindings_activate_event (G_OBJECT (window), event))
+		gtk_bindings_activate_event (G_OBJECT (combo), event);
 
 	return TRUE;
 }
@@ -502,7 +495,7 @@ color_combo_get_property (GObject *object,
 	GtkhtmlColorComboPrivate *priv;
 	GdkColor color;
 
-	priv = GTKHTML_COLOR_COMBO_GET_PRIVATE (object);
+	priv = GTKHTML_COLOR_COMBO (object)->priv;
 
 	switch (property_id) {
 		case PROP_CURRENT_COLOR:
@@ -556,7 +549,7 @@ color_combo_dispose (GObject *object)
 	GtkhtmlColorComboPrivate *priv;
 	gint ii;
 
-	priv = GTKHTML_COLOR_COMBO_GET_PRIVATE (object);
+	priv = GTKHTML_COLOR_COMBO (object)->priv;
 
 	if (priv->color_button != NULL) {
 		g_object_unref (priv->color_button);
@@ -603,14 +596,27 @@ color_combo_dispose (GObject *object)
 }
 
 static void
-color_combo_size_request (GtkWidget *widget,
-                          GtkRequisition *requisition)
+color_combo_get_preferred_width (GtkWidget *widget,
+				gint *minimum_width,
+				gint *natural_width)
 {
 	GtkhtmlColorComboPrivate *priv;
 
-	priv = GTKHTML_COLOR_COMBO_GET_PRIVATE (widget);
+	priv = GTKHTML_COLOR_COMBO (widget)->priv;
 
-	gtk_widget_get_preferred_size (priv->toggle_button, requisition, NULL);
+	gtk_widget_get_preferred_width (priv->toggle_button, minimum_width, natural_width);
+}
+
+static void
+color_combo_get_preferred_height (GtkWidget *widget,
+				gint *minimum_height,
+				gint *natural_height)
+{
+	GtkhtmlColorComboPrivate *priv;
+
+	priv = GTKHTML_COLOR_COMBO (widget)->priv;
+
+	gtk_widget_get_preferred_height (priv->toggle_button, minimum_height, natural_height);
 }
 
 static void
@@ -619,7 +625,7 @@ color_combo_size_allocate (GtkWidget *widget,
 {
 	GtkhtmlColorComboPrivate *priv;
 
-	priv = GTKHTML_COLOR_COMBO_GET_PRIVATE (widget);
+	priv = GTKHTML_COLOR_COMBO (widget)->priv;
 
 	gtk_widget_set_allocation (widget, allocation);
 	gtk_widget_size_allocate (priv->toggle_button, allocation);
@@ -711,7 +717,8 @@ color_combo_class_init (GtkhtmlColorComboClass *class)
 	object_class->dispose = color_combo_dispose;
 
 	widget_class = GTK_WIDGET_CLASS (class);
-	widget_class->size_request = color_combo_size_request;
+	widget_class->get_preferred_width = color_combo_get_preferred_width;
+	widget_class->get_preferred_height = color_combo_get_preferred_height;
 	widget_class->size_allocate = color_combo_size_allocate;
 
 	class->popup = color_combo_popup;
@@ -844,7 +851,8 @@ color_combo_init (GtkhtmlColorCombo *combo)
 	GtkWidget *window;
 	guint ii;
 
-	combo->priv = GTKHTML_COLOR_COMBO_GET_PRIVATE (combo);
+	combo->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		combo, GTKHTML_TYPE_COLOR_COMBO, GtkhtmlColorComboPrivate);
 
 	state = gtkhtml_color_state_new ();
 	gtkhtml_color_combo_set_state (combo, state);
