@@ -19,6 +19,7 @@
  */
 
 #include "gtkhtml-editor-private.h"
+#include "gtkhtml-stream.h"
 
 /******************************************************************************
  * Action Group Quick Reference
@@ -134,21 +135,6 @@
  *
  *****************************************************************************/
 
-static void
-insert_image_response_cb (GtkFileChooser *file_chooser,
-                          gint response,
-                          GtkhtmlEditor *editor)
-{
-	gchar *uri;
-
-	if (response != GTK_RESPONSE_OK)
-		return;
-
-	uri = gtk_file_chooser_get_uri (file_chooser);
-	gtkhtml_editor_insert_image (editor, uri);
-	g_free (uri);
-}
-
 static void
 insert_html_file_ready_cb (GFile *file,
                            GAsyncResult *result,
@@ -172,16 +158,15 @@ insert_html_file_ready_cb (GFile *file,
 
 	stream = gtk_html_begin (new_html);
 	gtk_html_write (html, stream, contents, length);
+	/* 'stream' is destroyed inside gtk_html_end */
 	gtk_html_end (html, stream, GTK_HTML_STREAM_OK);
-	g_object_unref (stream);
 
 	g_free (contents);
 
 	html = gtkhtml_editor_get_html (editor);
+	/* 'new_html' destroys gtk_html_insert_gtk_html itself */
 	gtk_html_insert_gtk_html (html, new_html);
 
-	g_object_unref (new_html);
-
 	goto exit;
 
 fail:
@@ -631,9 +616,32 @@ static void
 action_insert_image_cb (GtkAction *action,
                         GtkhtmlEditor *editor)
 {
-	gtkhtml_editor_insert_file (
-		editor, _("Insert Image"),
-		G_CALLBACK (insert_image_response_cb));
+	GtkWidget *dialog;
+	GFile *file;
+
+	dialog = gtkhtml_image_chooser_dialog_new (
+		_("Insert Image"), GTK_WINDOW (editor));
+
+	g_object_bind_property (
+		editor, "current-folder",
+		dialog, "current-folder",
+		G_BINDING_BIDIRECTIONAL |
+		G_BINDING_SYNC_CREATE);
+
+	file = gtkhtml_image_chooser_dialog_run (
+		GTKHTML_IMAGE_CHOOSER_DIALOG (dialog));
+
+	if (file != NULL) {
+		gchar *uri;
+
+		uri = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (dialog));
+		gtkhtml_editor_insert_image (editor, uri);
+		g_free (uri);
+
+		g_object_unref (file);
+	}
+
+	gtk_widget_destroy (dialog);
 }
 
 static void
@@ -815,7 +823,7 @@ action_mode_cb (GtkRadioAction *action,
 	action_group = editor->priv->html_context_actions;
 	gtk_action_group_set_visible (action_group, html_mode);
 
-        gtk_widget_set_sensitive (editor->priv->color_combo_box, html_mode);
+	gtk_widget_set_sensitive (editor->priv->color_combo_box, html_mode);
 
 	if (html_mode)
 		gtk_widget_show (editor->priv->html_toolbar);
