@@ -79,6 +79,10 @@ struct _GtkHTMLPrivate {
 	gboolean in_key_binding;
 
 	gchar *caret_first_focus_anchor;
+	gboolean is_first_focus;
+
+	GtkAdjustment *hadjustment;
+	GtkAdjustment *vadjustment;
 };
 
 void  gtk_html_private_calc_scrollbars  (GtkHTML                *html,
@@ -103,7 +107,6 @@ gchar *gtk_html_filename_from_uri	(const gchar		*uri);
 const gchar *_get_icondir (void) G_GNUC_CONST;
 const gchar *_get_gtkhtml_datadir (void) G_GNUC_CONST;
 const gchar *_get_localedir (void) G_GNUC_CONST;
-const gchar *_get_glade_datadir (void) G_GNUC_CONST;
 const gchar *_get_prefix (void) G_GNUC_CONST;
 const gchar *_get_sysconfdir (void) G_GNUC_CONST;
 const gchar *_get_datadir (void) G_GNUC_CONST;
@@ -118,9 +121,6 @@ const gchar *_get_libdir (void) G_GNUC_CONST;
 #undef GNOMELOCALEDIR
 #define GNOMELOCALEDIR _get_localedir ()
 
-#undef GLADE_DATADIR
-#define GLADE_DATADIR _get_glade_datadir ()
-
 #undef PREFIX
 #define PREFIX _get_prefix ()
 
