@@ -335,13 +335,8 @@ void  html_engine_draw                 (HTMLEngine *e,
 					gint        y,
 					gint        width,
 					gint        height);
-#if GTK_CHECK_VERSION(2,91,0)
-void  html_engine_expose               (HTMLEngine *e,
+void  html_engine_draw_cb              (HTMLEngine *e,
 					cairo_t    *cr);
-#else
-void  html_engine_expose               (HTMLEngine *e,
-					GdkEventExpose *event);
-#endif
 void  html_engine_draw_background      (HTMLEngine *e,
 					gint        x,
 					gint        y,
